LazyCell

Struct LazyCell 

pub struct LazyCell<T: 'static> { /* private fields */ }
A runtime-local accessor for lazily initialized JavaScript values.

This type provides safe access to cached JavaScript global values, ensuring the value is initialized on first access in the active runtime.

Example

#[wasm_bindgen]
extern "C" {
    #[wasm_bindgen(thread_local_v2, js_name = window)]
    pub static WINDOW: Window;
}

WINDOW.with(|window| {
    let doc = window.document();
});

Implementations

Source

impl<T> LazyCell<T>

pub fn with<F, R>(&'static self, f: F) -> R
where F: FnOnce(&T) -> R,

Run a closure with access to the cached value.