pub struct Runtime<'a> { /* private fields */ }Expand description
A handle to the active runtime, scoped to a with_runtime call.
Implementations
Sourceimpl Runtime<'_>
impl Runtime<'_>
Sourcepub fn insert_object<T: 'static>(&mut self, obj: T) -> ObjectHandle
pub fn insert_object<T: 'static>(&mut self, obj: T) -> ObjectHandle
Store a Rust value, returning an opaque handle to it.
Sourcepub fn object<T: 'static>(
&mut self,
handle: ObjectHandle,
) -> impl DerefMut<Target = T> + use<T>
pub fn object<T: 'static>( &mut self, handle: ObjectHandle, ) -> impl DerefMut<Target = T> + use<T>
Temporarily borrow a stored object by handle.
Sourcepub fn remove_object<T: 'static>(&mut self, handle: ObjectHandle) -> Option<T>
pub fn remove_object<T: 'static>(&mut self, handle: ObjectHandle) -> Option<T>
Permanently remove a stored value by handle, freeing the handle.