Runtime

Struct Runtime 

pub struct Runtime<'a> { /* private fields */ }
A handle to the active runtime, scoped to a with_runtime call.

Implementations

Source

impl Runtime<'_>

pub fn insert_object<T: 'static>(&mut self, obj: T) -> ObjectHandle

Store a Rust value, returning an opaque handle to it.

pub fn object<T: 'static>( &mut self, handle: ObjectHandle, ) -> impl DerefMut<Target = T> + use<T>

Temporarily borrow a stored object by handle.

pub fn remove_object<T: 'static>(&mut self, handle: ObjectHandle) -> Option<T>

Permanently remove a stored value by handle, freeing the handle.